from distutils.core import setup

setup(
		name = 'zathleteListClass',
		version = '1.0.0',
		py_modules = ['zathleteListClass'],
		author = 'surf',
		author_email = 'surfielda@aol.com',
		url = 'http://www.zurfgames.com',
		description = 'A simple printer of athlete lists',
	 )